#! /usr/bin/env python
# -*- coding: utf-8 -*-
from django.conf.urls import url

from gea.views import Home, catastros_locales, lugares, secciones, manzanas, \
parcelas, listado_alfabetico, caratula, solicitud, visacion, plano, set, \
catastro, dvapi, sie, ExpedienteList, ExpedienteDetail, PersonaList, \
PersonaDetail, CatastroLocalList, calendar

urlpatterns = [
    url(r'^$', Home.as_view(), name='home'),
    # Catastros Locales
    url(r'^catastros-locales/$', CatastroLocalList.as_view(), name='catastros_locales'),
#     url(r'^catastros-locales/$', catastros_locales, name='catastros_locales'),
#     url(r'^catastros-locales/(?P<l>[^/]+)/$', lugares),
#     url(r'^catastros-locales/(?P<l>[^/]+)/(?P<s>[^/]+)/$', secciones),
#     url(r'^catastros-locales/(?P<l>[^/]+)/(?P<s>[^/]+)/(?P<m>[^/]+)/$',
#         manzanas),
    url(r'^catastros-locales/%s' %
    '(?P<l>[^/]+)/(?P<s>[^/]+)/(?P<m>[^/]+)/(?P<p>[^/]+)/$', parcelas),
    # Listado alfabético
    url(r'^listado-alfabetico/$', listado_alfabetico,
        name='listado_alfabetico'),
    url(r'^listado-alfabetico/(?P<inicial>[^/]+)/$', listado_alfabetico,
        name="listado_alfabetico"),
    # Expedientes
    url(r'^expedientes/$', ExpedienteList.as_view(), name="expedientes"),
    url(r'^expedientes/(?P<pk>\d+)/$', ExpedienteDetail.as_view(),
        name="expediente"),
    # Personas
    url(r'^personas/$', PersonaList.as_view(), name="personas"),
    url(r'^personas/(?P<pk>\d+)/$', PersonaDetail.as_view(),
        name="persona"),
    # Notas
    url(r'^caratula/$', caratula, name="caratula"),
    url(r'^solicitud/$', solicitud, name="solicitud"),
    url(r'^visacion/$', visacion, name="visacion"),
    # Búsquedas
    url(r'^plano/$', plano),
    url(r'^set/$', set),
    url(r'^catastro/$', catastro),
    # Herramientas
    url(r'^dvapi/$', dvapi, name='dvapi'),
    url(r'^sie/$', sie, name='sie'),
    url(r'^cal/(?P<year>[0-9]{4})/(?P<month>[0-9]{2})/$', calendar, name='cal'),
#    url(r'^cal/$', calendar, name='cal'),
]



#!/usr/bin/python
# -*- coding: UTF-8 -*-

from setuptools import setup

setup(
    name='gea',
    version='0.2.6',
    description='Gestión de Expedientes de Agrimensores para Django.',
    author='Santiago Pestarini',
    author_email='santiago@pestarini.com.ar',
    url='http://pypi.python.org/pypi/gea/',
    packages=['gea'],
    package_data={
        'gea': ['templates/*.html', 'templatetags/*', 'static/*/*'],
    },
    license='LICENSE',
    long_description=open('README.rst', 'r').read(),
    install_requires=[
        'Django == 1.8.9',
        'django-grappelli == 2.8.1',
        'django-nested-admin == 2.1.8',
        'django-extensions == 1.7.6',
    ],   
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Utilities'
    ],
)

